@@ -1,15 +1,17 @@
 import requests
 import json
 
-class requestMode(object):
+
+class requestMode(object):  # ff
     post = "post"
     get = "get"
     put = "put"
-    delete = "delete"    
-        
-def sendRequest(url, header, params = "", content = "", 
-                rMode = requestMode.post):
-     
+    delete = "delete"
+
+
+def sendRequest(url, header, params="", content="",
+                rMode=requestMode.post):
+
     if rMode == "post":
         rMode = requests.post
     elif rMode == "get":
@@ -17,8 +19,8 @@ def sendRequest(url, header, params = "", content = "",
     elif rMode == "put":
         rMode = requests.put
     elif rMode == "delete":
-        rMode = requests.delete     
-    
+        rMode = requests.delete
+
     status = True
     try:
         response = rMode(
@@ -32,9 +34,9 @@ def sendRequest(url, header, params = "", content = "",
         else:
             status = False
         content = response.content
-    
+
     except requests.exceptions.RequestException:
         status = False
-        content = '%s Request failed'%url
-    
-    return(status, content)
\ No newline at end of file
+        content = '%s Request failed' % url
+
+    return(status, content)
